- outcome
Whether the operation was successfully performed
- message
Any information, particularly when the operation fails.
- data
The data after removing the columns without any data.
- metadata
Automated metadata is created based on the data. However, this relies
on data not previously coded, for example, if the status is coded as 0 and 1 rather
than 'absent' and 'present', the variable will be recognised as a quantitative
variable rather than categorical variable.
- any_type
All fields with data.
- quantitative
Fields recognised as quantitative.
- numerical
Fields recognised as continuous.
- count
Fields recognised as count. Count data is recognised from the field
name. If a field name starts with 'Number of', it is considered as count data.
- categorical
Fields recognised as categorical data.
- nominal
Fields recognised as nominal data. All categorical data with more
than two levels are recognised as nominal data.
- binary
Fields recognised as binary data. All categorical data with only
two levels are recognised as binary data.
- ordinal
Fields recognised as ordinal data. Any categorical data with
more than two levels and with the second character of all the levels being an '_'
are recognised as ordinal data.
- date
Fields recognised as date.
- time
Fields recognised as time.